monkey.ci.common.constants


blob-extensionclj/s


free-creditsclj/s


max-script-timeoutclj/s

Max msecs a build script can run before we terminate it

Max msecs a build script can run before we terminate it
raw docstring

plan-typesclj/s


pro-creditsclj/s


starter-creditsclj/s


starter-usersclj/s

cljdoc builds & hosts documentation for Clojure/Script libraries