monkey.ci.common.constants


blob-extensionclj/s

source

free-creditsclj/s

source

max-script-timeoutclj/s

Max msecs a build script can run before we terminate it

Max msecs a build script can run before we terminate it
sourceraw docstring

plan-typesclj/s

source

pro-creditsclj/s

source

starter-creditsclj/s

source

starter-usersclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries